# BEGIN SourceDeps(oneline):
BuildRequires: /usr/bin/doxygen /usr/bin/genhtml /usr/bin/lcov /usr/bin/man2html /usr/bin/nm /usr/bin/python /usr/bin/valgrind /usr/bin/xsltproc docbook-dtds gcc-c++ libdb4.7-devel
# END SourceDeps(oneline)
%define fedora 16
Summary:       A key/value pair database to store software configurations
Name:          elektra
Version:       0.7.0
Release:       alt1_7
Group:         System/Libraries
License:       BSD
URL:           http://www.libelektra.org
Source0:       http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
Patch0:        elektra-0.7.0-rename.patch
Patch1:        elektra-0.7.0-no_local.patch
# doxygen: to build the API documentation
# libxslt, docbook-style-xsl: to build man pages from docbook with xsltproc program
# db4-devel: for the Berkeley DB backend
# libxml2-devel: for the kdbtools library build
BuildRequires: doxygen db4-devel libxml2-devel docbook-style-xsl xsltproc libxslt
# gawk is used in src/libelektra/exportobjects.sh
BuildRequires: gawk
# gettext-devel: for the autoconf ICONV macro only
# GConf2-devel: for the testing GConf2 backend for Elektra
BuildRequires: libGConf-devel
BuildRequires: libltdl7-devel
BuildRequires: libtool gettext-devel
%if 0%{?fedora} > 10
BuildRequires: glibc-devel-static
%endif
Source44: import.info
Patch33: elektra-0.7.0-alt-as-needed.patch



%description
Elektra provides a universal and secure framework to store configuration
parameters in a hierarchical key-value pair mechanism, instead of each
program using its own text configuration files. This allows any program
to read and save its configuration with a consistent API, and allows
them to be aware of other applications' configurations, permitting
easy application integration. While architecturally similar to other OS
registries, Elektra does not have most of the problems found in those
implementations.

This package also contains a Berkeley DB backend for Elektra, to let 
Elektra use Berkeley DB databases to store its keys and daemon which can
be used as a proxy for access to the keys.


%package devel
Summary:      Include files and API documentation to build elektrified programs
Group:        Development/Other
Requires:     %{name} = %{version}-%{release}

%description devel
Elektra provides a universal and secure framework to store configuration
parameters in a hierarchical key-value pair tree.

This package contains development specific things as include files to 
create elektrified programs.



%prep
%setup -q
%patch0 -p1 -b .rename
%patch1 -p1 -b .local
%patch33 -p1



%build
export CFLAGS="$RPM_OPT_FLAGS -D_GNU_SOURCE"
export CXXFLAGS="$RPM_OPT_FLAGS -D_GNU_SOURCE"
%configure \
     --includedir=%{_includedir}/elektra \
     --program-prefix=%{name}- \
     --disable-static \
     --disable-rpath \
     --with-ulibdir=%{_libdir} \
     --with-docbook=%{_datadir}/xml/docbook/xsl-stylesheets \
     --with-kdbschemadir=%{_datadir}/sgml/%{name}-%{version} \
     --enable-iconv

# remove rpath from libtool
sed -i.rpath 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i.rpath 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

# Not used for now
# --disable-xmltest
# --with-hlvl-backenddir
# --with-default-backend
# --with-default-dbackend
#     --enable-ini \
#     --enable-berkeleydb \
#     --enable-gconf \
#     --enable-daemon \
#     --enable-python

make %{?_smp_mflags}


%install

make DESTDIR=$RPM_BUILD_ROOT install INSTALL='install -p'
find $RPM_BUILD_ROOT%{_libdir} -type f -a -name \*.la -exec rm {} \;

# Remove statically linked kdb - lib
rm $RPM_BUILD_ROOT%{_bindir}/*_static
rm $RPM_BUILD_ROOT%{_libdir}/*.a

# file in profile.d is sourced, remove shebang and execute bits,
# while keeping timestamps
touch -r $RPM_BUILD_ROOT%{_sysconfdir}/profile.d/elektra-elektraenv.sh __elektra-elektraenv_timestamp
sed -i -e 's;#!/bin/sh;;' $RPM_BUILD_ROOT%{_sysconfdir}/profile.d/elektra-elektraenv.sh
chmod a-x $RPM_BUILD_ROOT%{_sysconfdir}/profile.d/elektra-elektraenv.sh
touch -r __elektra-elektraenv_timestamp $RPM_BUILD_ROOT%{_sysconfdir}/profile.d/elektra-elektraenv.sh
rm __elektra-elektraenv_timestamp

#Fix symlink should be relative - Be aware of SONAME changes!
ln -fs ../libelektratools.so.2  $RPM_BUILD_ROOT%{_libdir}/elektra/libelektratools.so

## doc fixes
rm -rf __doc __doc-devel
mkdir __doc
mv  $RPM_BUILD_ROOT%{_datadir}/doc/elektra/* __doc
rm -rf $RPM_BUILD_ROOT%{_datadir}/doc/elektra
mkdir __doc-devel
mv  $RPM_BUILD_ROOT%{_datadir}/doc/elektra-devel/* __doc-devel
touch -r ChangeLog __doc-devel/api-html/*
rm -rf $RPM_BUILD_ROOT%{_datadir}/doc/elektra-devel


## man fixes (from program prefix)
mv $RPM_BUILD_ROOT%{_mandir}/man5/elektra-elektra.5 $RPM_BUILD_ROOT%{_mandir}/man5/elektra.5
mv $RPM_BUILD_ROOT%{_mandir}/man7/elektra-elektra.7 $RPM_BUILD_ROOT%{_mandir}/man7/elektra.7

# The init-script is disabled for now
rm -rf $RPM_BUILD_ROOT/etc/init.d/elektra-kdbd
#Own the directory where configuration will be stored.
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/kdb
# broken symlinks
find -L $RPM_BUILD_ROOT%{_libdir}/elektra -type l -delete


%post
elektra-kdb set -t dir system/sw > /dev/null 2>&1
elektra-kdb set system/sw/kdb/schemapath "%{_datadir}/sgml/elektra-%{version}/elektra.xsd" > /dev/null 2>&1 || :

%files
%doc AUTHORS COPYING ChangeLog README INSTALL
%doc __doc/*
#{_initrddir}/elektra-kdbd
%dir %{_sysconfdir}/kdb
%{_bindir}/elektra-kdb
%{_bindir}/elektra-preload
#{_sbindir}/elektra-kdbd
%{_libdir}/elektra
%{_libdir}/libelektra*.so.*
# Do not use (noreplace) for this config file.
%config %{_sysconfdir}/profile.d/*.sh
%{_mandir}/man1/*
%{_mandir}/man7/*
%{_mandir}/man5/*
%{_datadir}/sgml/elektra-%{version}/


%files devel
%doc __doc-devel/*
%{_includedir}/elektra/
%{_libdir}/libelektra.so
%{_libdir}/libelektra-cpp.so
%{_libdir}/libelektratools.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*



%changelog
* Sat Jun 09 2012 Igor Vlasenko <viy@altlinux.ru> 0.7.0-alt1_7
- update to new fc release

